pub fn get_num_outputs_with_amount(
db: &BlockchainDatabase,
tx_ro: &Snapshot,
amount: Amount,
) -> DbResult<u64>Expand description
Get the number of outputs with a given amount.
pub fn get_num_outputs_with_amount(
db: &BlockchainDatabase,
tx_ro: &Snapshot,
amount: Amount,
) -> DbResult<u64>Get the number of outputs with a given amount.